aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-gsm_a_gm.c
diff options
context:
space:
mode:
authoretxrab <etxrab@f5534014-38df-0310-8fa8-9805f1628bb7>2011-12-02 21:56:10 +0000
committeretxrab <etxrab@f5534014-38df-0310-8fa8-9805f1628bb7>2011-12-02 21:56:10 +0000
commit2d512d04a109aa516d3ea7576f7276ac164c1109 (patch)
tree1ed34d12aa683969d6852d2acc105be2e7468211 /epan/dissectors/packet-gsm_a_gm.c
parent5377bdeb9bd21b52e91c2ba03d82c440e454969a (diff)
From Pascal Quantin:
Add S1 related info to the DRX parameter dissection (IE common to 2G/3G/LTE) as specified in 3GPP 24.301 Release 9.8.0 chapter 10.5.5.6. https://bugs.wireshark.org/bugzilla/show_bug.cgi?id=6642 git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@40070 f5534014-38df-0310-8fa8-9805f1628bb7
Diffstat (limited to 'epan/dissectors/packet-gsm_a_gm.c')
-rw-r--r--epan/dissectors/packet-gsm_a_gm.c31
1 files changed, 16 insertions, 15 deletions
diff --git a/epan/dissectors/packet-gsm_a_gm.c b/epan/dissectors/packet-gsm_a_gm.c
index 1618882d43..c1b3f8ac51 100644
--- a/epan/dissectors/packet-gsm_a_gm.c
+++ b/epan/dissectors/packet-gsm_a_gm.c
@@ -607,26 +607,27 @@ static const value_string gsm_a_gmm_non_drx_timer_strings[] = {
/*
* CN Specific DRX cycle length coefficient, octet 3
* bit
- * 8 7 6 5 Iu mode specific
- * 0 0 0 0 CN Specific DRX cycle length coefficient not specified by the MS, ie. the
+ * 8 7 6 5 Iu and S1 mode specific
+ * 0 0 0 0 For Iu mode, CN Specific DRX cycle length coefficient not specified by the MS, ie. the
* system information value 'CN domain specific DRX cycle length' is used.
* (Ref 3GPP TS 25.331)
* 0 1 1 0 CN Specific DRX cycle length coefficient 6
* 0 1 1 1 CN Specific DRX cycle length coefficient 7
* 1 0 0 0 CN Specific DRX cycle length coefficient 8
* 1 0 0 1 CN Specific DRX cycle length coefficient 9
* All other values shall be interpreted as "CN Specific DRX cycle length coefficient not
* specified by the MS " by this version of the protocol.
* NOTE: In Iu mode this field (octet 3 bits 8 to 5) is used, but was spare in earlier
* versions of this protocol.
*/
static const range_string gsm_a_gmm_cn_spec_drs_cycle_len_coef_strings[] = {
- { 0x00, 0x05, "CN Specific DRX cycle length coefficient not specified by the MS" },
- { 0x06, 0x06, "CN Specific DRX cycle length coefficient 6" },
- { 0x07, 0x07, "CN Specific DRX cycle length coefficient 7" },
- { 0x08, 0x08, "CN Specific DRX cycle length coefficient 8" },
- { 0x09, 0x09, "CN Specific DRX cycle length coefficient 9" },
- { 0x0a, 0x0f, "CN Specific DRX cycle length coefficient not specified by the MS" },
+ { 0x00, 0x05, "CN Specific DRX cycle length coefficient / value not specified by the MS" },
+ { 0x06, 0x06, "CN Specific DRX cycle length coefficient 6 and T = 32" },
+ { 0x07, 0x07, "CN Specific DRX cycle length coefficient 7 and T = 64" },
+ { 0x08, 0x08, "CN Specific DRX cycle length coefficient 8 and T = 128" },
+ { 0x09, 0x09, "CN Specific DRX cycle length coefficient 9 and T = 256" },
+ { 0x0a, 0x0f, "CN Specific DRX cycle length coefficient / value not specified by the MS" },
{ 0, 0, NULL },
};
guint16
@@ -607,26 +607,27 @@ static const value_string gsm_a_gmm_non_drx_timer_strings[] = {
* system information value 'CN domain specific DRX cycle length' is used.
- * (Ref 3GPP TS 25.331)
- * 0 1 1 0 CN Specific DRX cycle length coefficient 6
- * 0 1 1 1 CN Specific DRX cycle length coefficient 7
- * 1 0 0 0 CN Specific DRX cycle length coefficient 8
- * 1 0 0 1 CN Specific DRX cycle length coefficient 9
+ * For S1 mode, DRX value not specified by the MS.
+ * (Ref 3GPP TS 25.331 and 36.304)
+ * 0 1 1 0 CN Specific DRX cycle length coefficient 6 and T = 32
+ * 0 1 1 1 CN Specific DRX cycle length coefficient 7 and T = 64
+ * 1 0 0 0 CN Specific DRX cycle length coefficient 8 and T = 128
+ * 1 0 0 1 CN Specific DRX cycle length coefficient 9 and T = 256
* All other values shall be interpreted as "CN Specific DRX cycle length coefficient not
@@ -607,26 +607,27 @@ static const value_string gsm_a_gmm_non_drx_timer_strings[] = {
* All other values shall be interpreted as "CN Specific DRX cycle length coefficient not
- * specified by the MS " by this version of the protocol.
- * NOTE: In Iu mode this field (octet 3 bits 8 to 5) is used, but was spare in earlier
+ * specified by the MS" and "DRX value not specified by the MS" by this version of the protocol.
+ * NOTE: For Iu mode and S1 mode, this field (octet 3 bits 8 to 5) is used, but was spare in earlier
* versions of this protocol.
*/